__author__ = """Lewis Bails"""
__email__ = 'lewis.bails@gmail.com'
__version__ = '0.1.5'
from .cem import CEM
__all__ = ["CEM"]
